{% load i18n %}

<div class="panel-body pull-right">
    <div id="aa-forum-mark-unread-button-{{ position }}" class="aa-forum-mark-unread-button">
        <a href="{% url 'aa_forum:forum_mark_all_as_read' %}" class="btn btn-warning btn-sm">
            {% translate "Mark all topics as read" %}
        </a>
    </div>
</div>
